@@ -1,6 +1,7 @@
 from pyspark.sql import DataFrame
 from pyspark.ml.feature import VectorAssembler, StandardScaler
 from .disassemble import disassemble
+from ..testing import assert_has_columns
 
 
 _SCALER_STATE = [
@@ -37,6 +38,9 @@ class Scaler:
         """
         if self._columns is None:
             self._columns = X.columns
+        else:
+            assert_has_columns(X, columns=self._columns)
+
         self._assembler = VectorAssembler(inputCols=self._columns, outputCol='features')
         assembled = self._assembler.transform(X).select('features')
         self._scaler = StandardScaler(
@@ -57,6 +61,8 @@ class Scaler:
         if not self._fitted:
             self.fit(X)
 
+        assert_has_columns(X, columns=self._columns)
+
         assembled = self._assembler.transform(X).select(
             'features', *[col for col in X.columns if col not in self._columns]
         )
